/*
APS Regression Workshop: Example 1

Relationship between wheat yield-loss and Fusarium head blight intensity
at Feekes' growth stage 11.2. 
Data from tables in Mesterhazy et al. Plant Dis. 87: 1107-1115. Data reported as
percentage losses. For this exercise, we converted to yield-loss in MT/ha, assuming 
a fixed yield for the disease-free check. (This conversion is an arbitrary decision 
for teaching purposes).

loss:	response variable (estimated yield loss in MT/ha) [Y]
FHB:	Fusarium head blight intensity [predictor variable; X]
FDK:	percentage of harvested wheat kernels with Fusarium symptoms
		(used later)
*/

data mes;
input FHB loss FDK;		
datalines;
23.8	1.440	14.6
23.9	1.525	15.9
24.8	1.535	19.6
28.5	1.675	18.4
30.8	1.775	19.3
32.4	1.830	27.1
36.5	2.215	29.7
38.2	2.250	33.1
38.2	2.165	32.0
51.8	2.935	43.7
;

*---Good to get a graph of data before analysis...;

title 'Regression Workshop (APS 2009), Example 1';
proc gplot data=mes;
	title2 'Plot of LOSS (Y) versus FHB (X)';
	symbol1 v=dot c=blue h=1.4;
	plot loss*FHB;
run;

*---Can get improved graphics....;

axis1 w=3 order= (20 to 60 by 10) minor=none value= (font=swiss h=2)
	label= (f=swiss h=2 'FHB field severity ("index")');
axis2 w=3 order= (1 to 3.5 by 0.5) minor=none value=(font=swiss h=2)
	label= (angle=90 f=swiss h=2 'Wheat yield loss (MT/ha)');
proc gplot data=mes;
	title2 'Plot of LOSS (Y) versus FHB (X)';
	symbol1 v=dot c=blue h=1.4;
	plot loss*FHB / haxis=axis1 vaxis=axis2;		*<--customized axes;
run;

*---Now do simple linear regression analysis;

proc reg data=mes;
	title2 'OLS: Simple linear regression model';
	model loss = FHB / r cli clm clb influence;	*--<options explained below ;
	plot loss*FHB ;
	plot loss*FHB / conf pred ;		*<--Observed, predicted, CI, and PI for each X;
run;

*---Options above in MODEL statement:
	r:			residual statistics and diagnostics
	clb:		confidence limits for the estimated parameters
	clm:		confidence limits for the mean at each X value
	cli:		prediction limits for Y at each X (wider than clm)
	influence:	statistics for the influence of each observation on results.;
		
/*
*---Control some of the appearance of graphs;
symbol1 v=dot c=blue h=1.4 ;
symbol2 v=none c=red w=3 i=join r=1 line=1;
symbol3 v=none c=black w=1.5 i=join r=2 line=3;	
symbol4 v=none c=blue w=1.5 i=join r=2 line=4;

proc reg data=mes;
	title2 'OLS: Simple linear regression model (with graphs)';
	model loss = FHB /  r cli clm clb influence ;

	plot loss*FHB ;					*<--Obs and predicted versus X;
	plot loss*FHB / conf pred ;		*<--Observed, predicted, CI, and PI for each X;
	plot r.*p.;						*<--Residual vs. predicted (REG notation);
	plot student.*p.;				*<--Studentized resid. vs predicted;
	plot r.*nqq.;					*<--Normal-quantile plot (look for normality);
									
	output out=mes_reg_out p=losshat r=r ucl=ucl lcl=lcl uclm=uclm lclm=lclm;
			*^--the above OUTPUT command puts certain results in designated file;
run;

*---Now do equivalent graphing with the GPLOT procedure (redundant here);
*---These are based on use of the stored results in the OUTPUT file;

proc gplot data=mes_reg_out;
symbol1 v=dot c=blue h=1.4 ;		*<--re-do the graphing options;
symbol2 v=none c=red w=3 i=join r=1 line=1;
symbol3 v=none c=black w=2 i=join r=2 line=3;
symbol4 v=none c=blue w=1.5 i=join r=2 line=4;

axis1 w=3 order= (20 to 60 by 10) minor=none value= (font=swiss h=2)
	label= (f=swiss h=2 'FHB field severity ("index")');
axis2 w=3 order= (1 to 3.5 by 0.5) minor=none value=(font=swiss h=2)
	label= (angle=90 f=swiss h=2 'Wheat yield loss (MT/ha)');

*^--Define some properties of the horizontal and vertical axes...;

plot (loss losshat)*FHB / overlay haxis=axis1 vaxis=axis2 ;
plot (loss losshat lclm uclm lcl ucl)*FHB / overlay haxis=axis1 vaxis=axis2;
plot r*losshat;
run;


	*ods html body='C:\Documents and Settings\madden.1\My Documents\My SAS Files\9.2\temp\temp.htm';
	*ods html body='C:\temp\temp.htm';

ods html;
ods graphics on;
proc reg data=mes;
	title2 'OLS: Simple linear regression model (with graphs)';
	model loss = FHB /  r cli clm clb influence ;

	plot loss*FHB / conf pred ;		*<--Observed, predicted, CI, and PI for each X;
	plot student.*p.;				*<--Studentized resid. vs predicted;
run;
ods graphics off;
ods html close;
run;

*/
run;


/*
*---Now do robust regression....;

*ods html;
*ods graphics on;

proc robustreg data=mes method = mm plots=all;
	model loss = FHB / diagnostics leverage;
	output out=mes_robust_out pred=predrob r=rrob stdp=sepred;
run;

*---You must download QUANTREG procedure if using 9.1 (comes standard with 9.2);
proc quantreg data=mes plots=all  ci=resampling ;
	title2 'Median regression, using new QUANTILE procedure';
	model loss = FHB / quantile=0.5 plot=quantplot;
	output out=mes_median_out pred=predmed res=rmed stdp=sepred;
run;
*proc print data=mes_median_out;run;

*---Now do OLS with several other procedures (that normally would be used for other stuff);

proc genmod data=mes;
	title2 'OLS regression using the GENMOD procedure';
	model loss = FHB;
	output out=mes_GENMOD_out pred=predloss resdev=res_scale;
run;

proc mixed data=mes;
	title2 'OLS (same as REML here) using MIXED procedure';
	model loss = FHB / s outm = mes_MIXED_out;
		*^--MIXED has special syntax for storing results in a file,
			(with prediction given name pred, etc.);
run;
*proc print data=mes_MIXED_out;run;

*---;
proc gam data=mes;
	title2 'OLS with GAM procedure (without any smoothing functins)';
	model loss = param(FHB);
	output out=mes_GAM_out predicted residual std uclm lclm;
	*^--GAM has a different syntax for the output file (one gives options, and then
		the variables are created with special names [print file to see]);
run;
proc print data=mes_GAM_out;run;

	*ods graphics off;
	*ods html close;
run;
*/

run;

