/*
APS Regression Workshop: Example 3

Data from D. Johnson et al. (2009). Plant Disease 93: 272-280.

Relationship between late blight incidence and cumulative 
solar radiation (sr) from 1 April to 31 July.

*/

data johnson;
input year sr incidence ;	
	loginc = log(incidence/100);		*<--possible transformation;
	logit = log(incidence/(100-incidence));
	cll = log(-log(1-(incidence/100)));
	logsr = log(sr);
datalines;
1990	2658	0.4
1991	2635	24
1992	2676	42
1993	2560	45
1994	2744	1.1
1995	2644	80
1996	2750	44
1997	2628	70
1998	2659	64
1999	2775	5
2000	2720	13
2001	2885	0.6
2002	2869	1.8
2003	2749	3
2004	2705	35
2005	2684	22
2006	2819	5.7
2007	2951	0.6
;

proc sort data=johnson out=johnson;		*<--put data in ascending order of SR;
	by sr;								*<--can help with certain types of plots;
run;

	*ods html;
	*ods graphics on;
title 'Late blight vs. solar radiation (Johnson et al. 2009)';
proc gplot data=johnson;
	title2 'Simple graph: logit vs. radiation';
	symbol1 v=dot c=blue h=1.4 line=1 i=none  ;
	plot logit*sr ;
run;

*goptions reset=all; 
symbol1 v=dot c=blue h=1.4 ;
symbol2 v=none c=red w=3 i=join r=1 line=1;
symbol3 v=none c=black w=1.5 i=join r=2 line=3;
symbol4 v=none c=blue w=1.5 i=join r=2 line=4;

*ods html body='temp.htm';
*ods graphics on;


*---Look at logit vs. X (similar to ln(incidence) vs X at low to moderate incidence;
		
proc reg data=johnson;
	title2 'linear relation between logit(Y) and X';
	model logit = sr / r  cli clm influence ;
	plot logit*sr ;
	plot logit*sr / conf pred ;
	plot student.*p.;
	plot r.*nqq.;
	plot rstudent.*p.;
	output out=johnson_reg_out p=inchat r=r ucl=ucl lcl=lcl uclm=uclm lclm=lclm;
run;
ods graphics off;
ods html close;
run;
*---Above, results were stored for fancier plots;

proc gplot data=johnson_reg_out;
title2 'Logit model';
symbol1 v=dot c=blue h=1.4 ;
symbol2 v=none c=red w=3 i=join r=1 line=1;
symbol3 v=none c=black w=2 i=join r=2 line=3;
symbol4 v=none c=blue w=1.5 i=join r=2 line=4;
axis1 w=3 order= (2500 to 3000 by 100 ) minor=none value= (font=swiss h=2)
	label= (f=swiss h=2 'Solar irradiance');
axis2 w=3 order= (-7 to 5 by 2) minor=none value=(font=swiss h=2)
	label= (angle=90 f=swiss h=2 'LOGIT Late blight incidence');

plot (logit inchat)*sr / overlay haxis=axis1 vaxis=axis2;
plot (logit inchat lclm uclm )*sr / overlay haxis=axis1 vaxis=axis2;
run;

*---Now the tricky part. Above, everything is in logits, but one may want
	results for predicted incidence. One back-transforms the fitted values,
	to get incidence-hat (not just logit-hat);

data johnson_reg_out; set johnson_reg_out; 
	predinc = 100.0/(1+exp(-inchat));	*<--fitted incidence (if start with logit);
	plclm=100.0/(1+exp(-lclm));			*<---predicted confidence limits for incidence;
	puclm=100.0/(1+exp(-uclm));
run;

proc gplot data=johnson_reg_out;
title2 'Logits back-transformed to predicted incidence';
symbol1 v=dot c=blue h=1.4 ;
symbol2 v=none c=red w=3 i=join r=1 line=1;
symbol3 v=none c=black w=2 i=join r=2 line=3;
symbol4 v=none c=blue w=1.5 i=join r=2 line=4;
axis1 w=3 order= (2500 to 3000 by 100 ) minor=none value= (font=swiss h=2)
	label= (f=swiss h=2 'Solar irradiance');
axis2 w=3 order= (0 to 100 by 10) minor=none value=(font=swiss h=2)
	label= (angle=90 f=swiss h=2 ' Late blight incidence');
plot (incidence predinc)*sr / overlay haxis=axis1 vaxis=axis2;
plot (incidence  predinc plclm puclm )*sr / overlay haxis=axis1 vaxis=axis2;
run;

/*
*---Now do robust regression for logit vs. X;
	ods html ;
	ods graphics on;
proc robustreg data=johnson method=mm plots=all;
	title2 'Robust regression, MM method';
	model logit = sr / diagnostics leverage;
	output out=john_rob_out pred=predrob r=rrob stdp=sepred;
run;

proc gplot data=john_rob_out;
axis1 w=3 order= (2500 to 3000 by 100 ) minor=none value= (font=swiss h=2)
	label= (f=swiss h=2 'Solar irradiance');
axis2 w=3 order= (-7 to 5 by 2) minor=none value=(font=swiss h=2)
	label= (angle=90 f=swiss h=2 'LOGIT Late blight incidence');
symbol2 v=none c=black w=3 i=join r=1 line=4;
plot (logit predrob)*sr / overlay haxis=axis1 vaxis=axis2;
plot rrob*predrob;
run;


*---Quantile (median) regression);

proc quantreg data=johnson plots=all ci=resampling;
	title2 'Median regression';
	model logit = sr ;
	output out=john_med_out pred=predmed res=rmed;
run;

proc gplot data=john_med_out;
axis1 w=3 order= (2500 to 3000 by 100 ) minor=none value= (font=swiss h=2)
	label= (f=swiss h=2 'Solar irradiance');
axis2 w=3 order= (-7 to 5 by 2) minor=none value=(font=swiss h=2)
	label= (angle=90 f=swiss h=2 'LOGIT Late blight incidence');
symbol2 v=none c=blue w=3 i=join r=1 line=3;
plot (logit predmed)*sr / overlay haxis=axis1 vaxis=axis2;
plot rmed*predmed;
run;


*---In above, predictions were stored in different files for each method, with
	different names. Now, these are combined (merged) and plotted together.;
ods graphics off;
ods html close;
run;

data combined; merge johnson_reg_out john_rob_out john_med_out; 
predincrob = 100.0/(1+exp(-predrob));	*<--get predicted incidence from pred. logit;
predincmed = 100.0/(1+exp(-predmed));
run;

proc gplot data=combined;
title2 'Comparison of OLS, robust, and median regression';
symbol1 v=dot c=blue h=2 ;
symbol2 v=none c=red w=3 i=join r=1 line=1;
symbol3 v=none c=black w=2 i=join r=1 line=3;
symbol4 v=none c=blue w=2 i=join r=1 line=4;
symbol5 v=dot c=blue h=2 i=rg w=2;
axis1 w=3 order= (2500 to 3000 by 100 ) minor=none value= (font=swiss h=2)
	label= (f=swiss h=2 'Solar irradiance');
axis2 w=3 order= (-7 to 5 by 2) minor=none value=(font=swiss h=2)
	label= (angle=90 f=swiss h=2 'LOGIT Late blight incidence');
axis3 w=3 order= (0 to 100 by 10) minor=none value=(font=swiss h=2)
	label= (angle=90 f=swiss h=2 ' Late blight incidence');
plot (logit inchat predrob predmed)*sr / overlay haxis=axis1 vaxis=axis2;
plot (incidence predinc predincrob predincmed)*sr / overlay haxis=axis1 vaxis=axis3;
run;
proc print data=combined;run;


*---Now get other quantile regressions...;
proc quantreg data=johnson;
	title2 'Q25 regression';
	model logit = sr /quantile=.25;
	output out=john_med_out25 pred=predmed25 res=rmed;
run;
proc print data=john_med_out25;run;
proc quantreg data=johnson;
	title2 'Q75 regression';
	model logit = sr / quantile=.75 ;
	output out=john_med_out75 pred=predmed75 res=rmed;
run;

*---Put different quantile regressions together, to get graph
	showing different predicted quantiles;

data combinedquant; merge john_med_out john_med_out25 john_med_out75;

proc gplot data=combinedquant;
title2 'Comparison of Q25, Q50 (median), and Q75 predictions';
plot (logit predmed predmed25 predmed75)*sr / overlay haxis=axis1 vaxis=axis2;
run;
proc print data=combinedquant;run;

ods graphics off;
ods html close;
run;
*/ ;run;quit;run;;





